__version__ = "0.11.9"

from sahi.annotation import BoundingBox, Category, Mask
from sahi.auto_model import AutoDetectionModel
from sahi.models.base import DetectionModel
from sahi.prediction import ObjectPrediction
